pub struct WmxSite {
pub permission_level: Option<String>,
pub site_url: Option<String>,
}Expand description
Contains permission level information about a Search Console site. For more information, see Permissions in Search Console.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get sites (response)
Fields
permission_level: Option<String>The user’s permission level for the site.
site_url: Option<String>The URL of the site.